## ----setup, include=FALSE------------------------------------------------
#setwd("/Users/Xavi/Dropbox/xavi-umh/docencia/")
#setwd("~/OneDrive - Universidad Miguel Hernández de Elche/xavi-umh/docencia/TEIM/2016-2017/temas/tema04")
 library(knitr)
 library(rmarkdown)
 library(xtable)
 library(highlight)
library(stargazer)
library(texreg)
library(caret)
library(gvlma)

options(xtable.comment = FALSE)
knitr::opts_chunk$set(width.cutoff=100, fig.width=3, fig.height=2.8, size="scriptsize", warning=FALSE, message=FALSE, echo=FALSE, tidy=TRUE, width=60)
knitr::opts_chunk$set(tidy.opts=list(width.cutoff=60))

## ---- eval=TRUE, echo=TRUE-----------------------------------------------
R2gauss<- function(y,model){
    moy<-mean(y)
    N<- length(y)
    p<-length(model$coefficients)-1
    SSres<- sum((y-predict(model))^2)
    SStot<-sum((y-moy)^2)
    R2<-1-(SSres/SStot)
    Rajust<-1-(((1-R2)*(N-1))/(N-p-1))
    return(data.frame(R2,Rajust,SSres,SStot))
}

## ----echo=TRUE, eval=FALSE,results='hide', fig.width=7-------------------
## pdf("img/valida1.pdf")
## par(mfrow=c(2,2)) # init 4 charts in 1 panel
## plot(modelo1c)
## dev.off()

## ---- out.width = "70px", fig.align="center"-----------------------------
knitr::include_graphics("img/validacion4.pdf")

## ----echo=TRUE, results='hide', eval=FALSE-------------------------------
## #Normalidad de los Residuos
## normalidad<-shapiro.test(modelo1c$residuals)
## 
## #Heterocedasticidad de los Residuos
## library(lmtest)
## hetero1<-bptest(modelo1c)

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## library(gvlma)
## gvlma(modelo1c)

## ---- echo=TRUE, tidy=FALSE----------------------------------------------
library(BCA)
data(Eggs)
fit.4<-glm(Cases ~ Egg.Pr + Easter +
             First.Week + Month + 
           Beef.Pr + Cereal.Pr +
          Egg.Pr:Easter, 
            family = "gaussian", 
             data = Eggs)


## ------------------------------------------------------------------------
summary(fit.4)

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## R2gauss(Eggs$Cases, fit.4)

## ---- echo=FALSE, results='asis'-----------------------------------------
kable(R2gauss(Eggs$Cases, fit.4),digits=3, caption="Bondad de ajuste del modelo")

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## # diagnostic plot
## layout(matrix(c(1,2,3,4),2,2)) # optional 4 graphs/page
## plot(fit.4)

## ---- echo=TRUE----------------------------------------------------------
residuos<-fit.4$residuals
t.test(residuos)

## ---- echo=TRUE----------------------------------------------------------
res.st<-scale(fit.4$residuals)
##Shapiro-Wilk Normality Test
shapiro.test(res.st)

## ---- echo=TRUE----------------------------------------------------------
library(lmtest) 
bptest(fit.4)

## ---- echo=TRUE, fig.width=7---------------------------------------------
# Assessing Outliers
library(car)
outlierTest(fit.4) # Bonferonni p-value for most extreme obs

## ---- echo=TRUE, fig.width=7 , eval=FALSE--------------------------------
## # Influential Observations
## # added variable plots
## avPlots(fit.4)

## ---- echo=TRUE, fig.width=7---------------------------------------------
# Cook's D plot
# identify D values > 4/(n-k-1) 
cutoff <- 4/((nrow(Eggs)-length(fit.4$coefficients)-2)) 
plot(fit.4, which=4, cook.levels=cutoff)

## ---- echo=TRUE, fig.width=7---------------------------------------------
# Influence Plot 
influencePlot(fit.4,	id.method="identify", main="Influence Plot", sub="Circle size is proportial to Cook's Distance" )

## ---- echo=TRUE----------------------------------------------------------
# Evaluate Collinearity
vif(fit.4) # variance inflation factors 

## ---- echo=TRUE----------------------------------------------------------
# Evaluate Collinearity
sqrt(vif(fit.4)) > 2 # problem?

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## # Evaluate Nonlinearity
## # component + residual plot
## crPlots(fit.4)
## # Ceres plots
## ceresPlots(fit.4)

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## # Evaluate Nonlinearity
## # component + residual plot
## crPlots(fit)
## # Ceres plots
## ceresPlots(fit.4)

## ----echo=FALSE----------------------------------------------------------
fit.4b<-glm(Cases ~ Egg.Pr + Easter +
             First.Week + Month + 
           Beef.Pr + Cereal.Pr 
          , 
            family = "gaussian", 
             data = Eggs)

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## # Evaluate Nonlinearity # component + residual plot
## crPlots(fit.4b)

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## # Ceres plots
## ceresPlots(fit.4b)

## ---- echo=TRUE----------------------------------------------------------
# Test for Autocorrelated Errors
durbinWatsonTest(fit.4)

## ----echo=FALSE, fig.width=8, fig.heigth=14------------------------------
acf(fit.4$residuals)

## ----echo=FALSE, fig.width=8, fig.heigth=14------------------------------
pacf(fit.4$residuals)

## ---- echo=TRUE, eval=FALSE----------------------------------------------
## # Global test of model assumptions
## gvmodel <- gvlma(fit.4)
## summary(gvmodel)

## ---- tydy=FALSE, echo=TRUE----------------------------------------------
fit.4v<-lm(Cases ~ Egg.Pr + Easter +
             First.Week + Month + 
           Beef.Pr + Cereal.Pr +
          Egg.Pr:Easter, 
             data = Eggs)


## ---- echo=TRUE, eval=FALSE----------------------------------------------
## # Global test of model assumptions
## gvmodel <- gvlma(fit.4v)
## gvmodel
## plot(gvmodel)

## ---- echo=TRUE, tidy=FALSE----------------------------------------------

Nuevos.Datos<-data.frame(Egg.Pr=100, 
                         Beef.Pr=130, 
                         Cereal.Pr=105, 
                         Easter="Easter",
                         First.Week="No", 
                         Month="April")
predict(fit.4, Nuevos.Datos,type="response" ,se.fit=TRUE)


## ---- echo=TRUE,  tidy=FALSE---------------------------------------------

Nuevos.Datos<-data.frame(Egg.Pr=100, 
                         Beef.Pr=130, 
                         Cereal.Pr=105, 
                         Easter="Pre Easter",
                         First.Week="Yes", 
                         Month="March")
predict(fit.4, Nuevos.Datos,type="response" ,se.fit=TRUE)


## ---- echo=TRUE,  tidy=FALSE---------------------------------------------

Nuevos.Datos<-data.frame(Egg.Pr=100, 
                         Beef.Pr=130, 
                         Cereal.Pr=105, 
                         Easter="Post Easter",
                         First.Week="Yes", 
                         Month="April")
predict(fit.4, Nuevos.Datos,type="response" ,se.fit=TRUE)


## ---- echo=TRUE,  tidy=FALSE---------------------------------------------

Nuevos.Datos<-data.frame(Egg.Pr=100, 
                         Beef.Pr=130, 
                         Cereal.Pr=105, 
                         Easter="Non Easter",
                         First.Week="Yes", 
                         Month="October")
predict(fit.4, Nuevos.Datos,type="response" ,se.fit=TRUE)


## ---- echo=TRUE,  tidy=FALSE---------------------------------------------

Nuevos.Datos<-data.frame(Egg.Pr=100, 
                         Beef.Pr=130, 
                         Cereal.Pr=105, 
                         Easter="Non Easter",
                         First.Week="No", 
                         Month="October")
predict(fit.4, Nuevos.Datos,type="response" ,se.fit=TRUE)


